@@ -3,7 +3,7 @@ use strict;
 use warnings;
 package YAML::PP::Loader;
 
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 use YAML::PP::Parser;
 use YAML::PP::Constructor;
@@ -12,10 +12,15 @@ use YAML::PP::Reader;
 sub new {
     my ($class, %args) = @_;
 
-    my $bool = delete $args{boolean} // 'perl';
+    my $cyclic_refs = delete $args{cyclic_refs} || 'allow';
+    my $schema = delete $args{schema} // YAML::PP->default_schema(
+        boolean => 'perl',
+    );
+
     my $parser = delete $args{parser} || YAML::PP::Parser->new;
     my $constructor = delete $args{constructor} || YAML::PP::Constructor->new(
-        boolean => $bool,
+        schema => $schema,
+        cyclic_refs => $cyclic_refs,
     );
     if (keys %args) {
         die "Unexpected arguments: " . join ', ', sort keys %args;
@@ -23,6 +28,7 @@ sub new {
     my $self = bless {
         parser => $parser,
         constructor => $constructor,
+        schema => $schema,
     }, $class;
     $parser->set_receiver($constructor);
     return $self;
@@ -30,6 +36,7 @@ sub new {
 
 sub parser { return $_[0]->{parser} }
 sub constructor { return $_[0]->{constructor} }
+sub schema { return $_[0]->{schema} }
 
 sub load_string {
     my ($self, $yaml) = @_;
